==> okta-sdk-impl-0.10.0-sources.jar: com/okta/sdk/impl/resource/DefaultGroupBuilder.java <==
/*
 * Copyright 2017 Okta
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.okta.sdk.impl.resource;

import com.okta.sdk.client.Client;
import com.okta.sdk.lang.Strings;
import com.okta.sdk.resource.group.GroupBuilder;
import com.okta.sdk.resource.group.Group;
import com.okta.sdk.resource.group.GroupProfile;

public class DefaultGroupBuilder implements GroupBuilder {

    private String name;
    private String description;

    @Override
    public GroupBuilder setName(String name) {
        this.name = name;
        return this;
    }

    @Override
    public GroupBuilder setDescription(String description) {
        this.description = description;
        return this;
    }

    @Override
    public Group buildAndCreate(Client client) {

        Group group = client.instantiate(Group.class);
        group.setProfile(client.instantiate(GroupProfile.class));
        group.getProfile().setName(name);
        if (Strings.hasText(description)) group.getProfile().setDescription(description);

        return client.createGroup(group);
    }
}

==> okta-sdk-impl-1.5.2-sources.jar: com/okta/sdk/impl/resource/DefaultGroupBuilder.java <==
/*
 * Copyright 2017 Okta
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.okta.sdk.impl.resource;

import com.okta.sdk.client.Client;
import com.okta.commons.lang.Strings;
import com.okta.sdk.resource.group.GroupBuilder;
import com.okta.sdk.resource.group.Group;
import com.okta.sdk.resource.group.GroupProfile;

public class DefaultGroupBuilder implements GroupBuilder {

    private String name;
    private String description;

    @Override
    public GroupBuilder setName(String name) {
        this.name = name;
        return this;
    }

    @Override
    public GroupBuilder setDescription(String description) {
        this.description = description;
        return this;
    }

    @Override
    public Group buildAndCreate(Client client) {

        Group group = client.instantiate(Group.class);
        group.setProfile(client.instantiate(GroupProfile.class));
        group.getProfile().setName(name);
        if (Strings.hasText(description)) group.getProfile().setDescription(description);

        return client.createGroup(group);
    }
}
